@@ -1,5 +1,5 @@
 class Event < CouchRest::ExtendedDocument
-  use_database TEST_SERVER.default_database
+  use_database DB
   
   property :subject
   property :occurs_at, :cast_as => 'Time', :send => 'parse'
